@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 1988-2006 University of Washington
+ * Copyright 1988-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@
  *		Internet: MRC@CAC.Washington.EDU
  *
  * Date:	27 July 1988
- * Last Edited:	6 December 2006
+ * Last Edited:	11 September 2007
  *
  * This original version of this file is
  * Copyright 1988 Stanford University
@@ -529,7 +529,7 @@ void rfc822_parse_content (BODY *body,STRING *bs,char *h,unsigned long depth,
 
 void rfc822_parse_content_header (BODY *body,char *name,char *s)
 {
-  char c,*t;
+  char c,*t,tmp[MAILTMPLEN];
   long i;
   STRINGLIST *stl;
   rfc822_skipws (&s);		/* skip leading comments */
@@ -585,14 +585,25 @@ void rfc822_parse_content_header (BODY *body,char *name,char *s)
       if (!(name = rfc822_parse_word (s,tspecials))) break;
       c = *name;		/* remember delimiter */
       *name = '\0';		/* tie off type */
-      s = ucase (rfc822_cpy(s));/* search for body type */
-      for (i = 0; (i <= TYPEMAX) && body_types[i] &&
-	     strcmp (s,body_types[i]); i++);
-				/* record body type index */
-      body->type = (i <= TYPEMAX) ? (unsigned short) i : TYPEOTHER;
+				/* search for body type */
+      for (i = 0,s = rfc822_cpy (s);
+	   (i <= TYPEMAX) && body_types[i] &&
+	     compare_cstring (s,body_types[i]); i++);
+      if (i > TYPEMAX) {	/* fell off end of loop? */
+	body->type = TYPEOTHER;	/* coerce to X-UNKNOWN */
+	sprintf (tmp,"MIME type table overflow: %.100s",s);
+	MM_LOG (tmp,PARSE);
+      }
+      else {			/* record body type index */
+	body->type = (unsigned short) i;
 				/* and name if new type */
-      if (body_types[body->type]) fs_give ((void **) &s);
-      else body_types[body->type] = s;
+	if (body_types[body->type]) fs_give ((void **) &s);
+	else {			/* major MIME body type unknown to us */
+	  body_types[body->type] = ucase (s);
+	  sprintf (tmp,"Unknown MIME type: %.100s",s);
+	  MM_LOG (tmp,PARSE);
+	}
+      }
       *name = c;		/* restore delimiter */
       rfc822_skipws (&name);	/* skip whitespace */
       if ((*name == '/') &&	/* subtype? */
@@ -610,17 +621,32 @@ void rfc822_parse_content_header (BODY *body,char *name,char *s)
       }
       rfc822_parse_parameter (&body->parameter,name);
     }
+
     else if (!strcmp (name+1,"RANSFER-ENCODING")) {
       if (!(name = rfc822_parse_word (s,tspecials))) break;
+      c = *name;		/* remember delimiter */
       *name = '\0';		/* tie off encoding */
-      s = ucase (rfc822_cpy(s));/* search for body encoding */
-      for (i = 0; (i <= ENCMAX) && body_encodings[i] &&
-	   strcmp (s,body_encodings[i]); i++);
-				/* record body encoding index */
-      body->encoding = (i <= ENCMAX) ? (unsigned short) i : ENCOTHER;
+				/* search for body encoding */      
+      for (i = 0,s = rfc822_cpy (s);
+	   (i <= ENCMAX) && body_encodings[i] &&
+	     compare_cstring (s,body_encodings[i]); i++);
+      if (i > ENCMAX) {		/* fell off end of loop? */
+	body->encoding = ENCOTHER;
+	sprintf (tmp,"MIME encoding table overflow: %.100s",s);
+	MM_LOG (tmp,PARSE);
+      }
+      else {			/* record body encoding index */
+	body->encoding = (unsigned short) i;
 				/* and name if new encoding */
-      if (body_encodings[body->encoding]) fs_give ((void **) &s);
-      else body_encodings[body->encoding] = ucase (cpystr (s));
+	if (body_encodings[body->encoding]) fs_give ((void **) &s);
+	else {
+	  body_encodings[body->encoding] = ucase (s);
+	  sprintf (tmp,"Unknown MIME transfer encoding: %.100s",s);
+	  MM_LOG (tmp,PARSE);
+	}
+      }
+      *name = c;		/* restore delimiter */
+      /* ??check for cruft here?? */
     }
     break;
   default:			/* otherwise unknown */
